@@ -1,17 +1,16 @@
-import time
 import random
-import numpy as np
+import time
 import shutil
+# from manimlib.utils.config_ops import digest_config
+# from manimlib.scene.scene_file_writer import SceneFileWriter
 from manimlib import Scene, Point, Camera, ShowCreation, Write, Color, VGroup
-from manimlib.utils.config_ops import digest_config
 from manimlib.extract_scene import get_scene_config
-from manimlib.scene.scene_file_writer import SceneFileWriter
 import manimlib.config
-
 from manimlib.config import Size
-from manimlib.utils.color import rgb_to_hex
 from .tools import ppath
 from .plot import Plot
+from .onlinetex import tex_to_svg_file_online
+import manimlib.mobject.svg.tex_mobject
 
 __all__ = ["EagerModeScene", "JupyterModeScene", "Size", "SceneArgs"]
 
@@ -20,7 +19,7 @@ class SceneArgs:
     # write_file = False
     # file_name = None
     # skip_animations = False  # "Save the last frame"
-    color = rgb_to_hex([0.3, 0.4, 0.5])  # Background color"
+    color = None  # Background color"
     full_screen = False
     gif = False
     resolution = '1920x1080'
@@ -37,6 +36,7 @@ class SceneArgs:
     frame_rate = None
     video_dir = None  # directory to write video
     start_at_animation_number = None
+    use_online_tex = False
 
 
 class EagerModeScene(Scene):
@@ -44,7 +44,7 @@ class EagerModeScene(Scene):
         self,
         write_file=False,
         file_name=None,
-        screen_size=Size.medium,
+        screen_size=Size.big,
         scene_name='EagerModeScene',
         CONFIG=None,
     ):
@@ -63,6 +63,10 @@ class EagerModeScene(Scene):
             if SceneArgs.gif is True:
                 args_dict["transparent"] = False
 
+        if SceneArgs.use_online_tex:
+            print("Use online latex compiler")
+            manimlib.mobject.svg.tex_mobject.tex_to_svg_file = tex_to_svg_file_online
+
         self.config = manimlib.config.get_configuration(args)
         self.scene_config = get_scene_config(self.config)
 
@@ -75,6 +79,17 @@ class EagerModeScene(Scene):
         self.setup()
         self.plt = Plot()
 
+        self.episodes = []
+        self.current_episode = 1
+        self.current_animation = 0
+        self.loop_start_animation = None
+        self.pause_start_animation = 0
+
+    def play(self, *args, run_time=1, **kwargs):
+        """TODO:"""
+        super().play(*args, run_time=run_time, **kwargs)
+        self.current_animation += 1
+
     def hold_on(self):
         """ Equal to self.tear_down(). """
         self.stop_skipping()
@@ -103,21 +118,59 @@ class EagerModeScene(Scene):
     def embed(self):
         super().embed()
 
-    def plot(self, x, y, color=None, width=2, axes_ratio=0.62, show_axes=True):
-        self.plt.plot(x, y, color, width, axes_ratio, show_axes)
+    def plot(self,
+             x,
+             y,
+             color=None,
+             width=2,
+             axes_ratio=0.62,
+             scale_ratio=None,
+             num_decimal_places=(1, 1),
+             show_axes=True,
+             include_tip=True,
+             x_label='x',
+             y_label='y'):
+
+        """
+        params
+        ------
+
+        scale_ratio: Scale ratio of coordinate axis. i.e. y / x .
+        num_decimal_places: Number of significant digits of coordinate_labels.
+        """
+        self.plt.plot(x, y, color, width, axes_ratio, scale_ratio, show_axes, include_tip, num_decimal_places,
+                      x_label, y_label)
 
     def plot3d(self, x, y, z, width=2, axes_ratio=0.62, show_axes=True):
+        """TODO"""
         pass
 
     def get_plot_mobj(self):
         self.plt.gen_axes_lines()
-        return VGroup(*self.plt.get_axes_lines())
+        return self.plt.get_axes_lines()
 
     def get_plot_axes(self):
         return self.plt.get_axes()
 
-    def show_plot(self):
-        self.add(self.get_plot_mobj())
+    def show_plot(self, play=True):
+        axes_lines_dict = self.get_plot_mobj()
+
+        random.seed(time.time())
+        if play:
+            def play_func(Func):
+                if axes_lines_dict['axes']:
+                    self.play(ShowCreation(VGroup(*axes_lines_dict["axes"])),
+                              run_time=1)
+                self.play(Func(VGroup(*axes_lines_dict["line"])), run_time=1)
+
+            if random.random() > 0.5:
+                play_func(Write)
+            else:
+                play_func(ShowCreation)
+        else:
+            self.add(VGroup(*axes_lines_dict["line"],
+                            *axes_lines_dict["axes"]))
+
         self.plt = Plot()
 
 
