@@ -1,11 +1,6 @@
 import os
 import sys
-from sparrow.file_ops import path
-
-
-def ppath(string, file=__file__) -> str:
-    """Path in package"""
-    return path(os.path.join(os.path.dirname(file), string))
+from sparrow.file_ops import ppath
 
 
 def calc_number_digit(number):
